<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>Start het programma met het opgegeven afbeeldingsbestandspad.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>U kunt tevens afbeeldingen naar het venster slepen.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="34"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>Geen van de handelingen in dit programma veranderen de afbeeldingen op de schijf.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <source>Context menu option explanation:</source>
        <translation>Rechtermuisknopmenu-uitleg:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>Houdt het venster boven andere vensters.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>Voorkomt per ongeluk sluiten (bijv. door te dubbelklikken op het venster).</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Version: %1</source>
        <translation>Versie: %1</translation>
    </message>
    <message>
        <source>Copyright (c) 2020 %1</source>
        <translation type="vanished">Copyright (c) 2020 %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Logo designed by %1</source>
        <translation>Logo gemaakt door %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Gebouwd met Qt %1 (%2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Source code</source>
        <translation>Broncode</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>Contributors</source>
        <translation>Bijdragers</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>List of contributors on GitHub</source>
        <translation>Lijst met bijdragers op GitHub</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>Met dank aan alle personen die hebben bijgedragen aan dit project.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>Translators</source>
        <translation>Vertalers</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>Ik wil graag de volgende mensen bedanken die vrijwillig hebben bijgedragen aan vertalingen.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="131"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1 is gebouwd met de volgende vrijesoftwarebibliotheken:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="155"/>
        <source>&amp;Special Thanks</source>
        <translation>&amp;Met dank aan</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="157"/>
        <source>&amp;Third-party Libraries</source>
        <translation>Ex&amp;terne bibliotheken</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Your Rights</source>
        <translation>Uw rechten</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="48"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation>Voorkom dat het zoomniveau, de draaiing en spiegeling worden hersteld na wisselen van afbeelding.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>Copyright (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="95"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1 is uitgebracht onder de MIT-licentie.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>Deze licentie biedt een hoop vrijheden:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="97"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>U mag %1 gratis gebruiken, voor welk doeleinde dan ook</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>You are free to distribute %1</source>
        <translation>U mag %1 vrij verspreiden</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="99"/>
        <source>You can study how %1 works and change it</source>
        <translation>U kunt bekijken hoe %1 werkt en aanpassingen doen</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="100"/>
        <source>You can distribute changed versions of %1</source>
        <translation>U mag aangepaste versie van %1 vrij verspreiden</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>De MIT-licentie garandeert u deze vrijheid, en niemand mag deze vrijheid wegnemen.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="130"/>
        <source>Third-party Libraries used by %1</source>
        <translation>Door %1 gebruikte externe bibliotheken</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="153"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="154"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="156"/>
        <source>&amp;License</source>
        <translation>&amp;Licentie</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <location filename="../graphicsscene.cpp" line="100"/>
        <source>Drag image here</source>
        <translation>Sleep een afbeelding hierheen</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <source>File url list is empty</source>
        <translation type="vanished">De bestandspadlijst is leeg</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="50"/>
        <source>File is not a valid image</source>
        <translation>Het bestand is geen afbeelding</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="54"/>
        <location filename="../graphicsview.cpp" line="58"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>De afbeeldingsgegevens zijn beschadigd of worden niet ondersteund</translation>
    </message>
    <message>
        <source>Image data is invalid</source>
        <translation type="vanished">Beschadigde afbeeldingsgegevens</translation>
    </message>
    <message>
        <source>Not supported mimedata: %1</source>
        <translation type="vanished">Niet-ondersteunde mime-gegevens: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>File url list is empty</source>
        <translation>De bestandspadlijst is leeg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Image data is invalid</source>
        <translation>Beschadigde afbeeldingsgegevens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Not supported mimedata: %1</source>
        <translation>Niet-ondersteunde mime-gegevens: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Image From Clipboard</source>
        <translation>Afbeelding van klembord</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="777"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation>Weet u zeker dat u “%1” naar de prullenbak wilt verplaatsen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Failed to move file to trash</source>
        <translation>Verplaatsen naar prullenbak mislukt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation>Het bestand kan niet naar de prullenbak worden verplaatst, mogelijk door een rechtenprobleem of systeembeperking.</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Copy P&amp;ixmap</source>
        <translation>P&amp;ixmap kopiëren</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="115"/>
        <source>Copy &amp;File Path</source>
        <translation>&amp;Bestandspad kopiëren</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="133"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="118"/>
        <location filename="../aboutdialog.cpp" line="41"/>
        <source>Stay on top</source>
        <translation>Altijd bovenop</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <location filename="../aboutdialog.cpp" line="44"/>
        <source>Protected mode</source>
        <translation>Beschermde modus</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="120"/>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation>Bewerkingen onthouden</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Zoom in</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Zoom out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Pause/Resume Animation</source>
        <translation>Animatie pauzeren/hervatten</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Animation Go to Next Frame</source>
        <translation>Ga naar volgend animatieframe</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Horizontaal spiegelen</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="112"/>
        <source>Fit to view</source>
        <translation>Inpassen</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Fit to width</source>
        <translation>Aanpassen aan breedte</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="116"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="101"/>
        <source>Toggle Checkerboard</source>
        <translation>Schaakbordpatroon aan/uit</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="95"/>
        <source>&amp;Open...</source>
        <translation>&amp;Openen…</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Actual size</source>
        <translation>Ware grootte</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Toggle maximize</source>
        <translation>Maximaliseren aan/uit</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Rotate right</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Rotate left</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Previous image</source>
        <translation>Vorige afbeelding</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Next image</source>
        <translation>Volgende afbeelding</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="776"/>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Move to Trash</source>
        <translation>Verplaatsen naar prullenbak</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="121"/>
        <source>Configure...</source>
        <translation>Instellen...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="122"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>Tonen in bestandsbeheer</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="131"/>
        <source>Show in directory</source>
        <translation>Tonen in map</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="134"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>Afbeeldingsmetagegevens</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>Oorsprong</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>Afbeelding</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>Camera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="35"/>
        <source>%1 File</source>
        <translation>%1-bestand</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>Omschrijving</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>Uitgebreide foto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="47"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Dimensions</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="54"/>
        <source>Aspect ratio</source>
        <translation>Beeldverhouding</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Frame count</source>
        <translation>Aantal frames</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Item type</source>
        <translation>Soort item</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Folder path</source>
        <translation>Bestandspad</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date created</source>
        <translation>Gemaakt op</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="72"/>
        <source>Date modified</source>
        <translation>Bewerkt op</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Title</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Subject</source>
        <translation>Onderwerp</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Rating</source>
        <translation>Waardering</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Tags</source>
        <translation>Labels</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="87"/>
        <source>Comments</source>
        <translation>Opmerkingen</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Authors</source>
        <translation>Makers</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Date taken</source>
        <translation>Genomen op</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Program name</source>
        <translation>Programmanaam</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="100"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Horizontal resolution</source>
        <translation>Horizontale resolutie</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Vertical resolution</source>
        <translation>Verticale resolutie</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Resolution unit</source>
        <translation>Resolutie-eenheid</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="109"/>
        <source>Colour representation</source>
        <translation>Kleurweergave</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera maker</source>
        <translation>Camerafabrikant</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>Camera model</source>
        <translation>Cameramodel</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>F-stop</source>
        <translation>Openingsverhouding</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Exposure time</source>
        <translation>Belichtingstijd</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>ISO speed</source>
        <translation>ISO-snelheid</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Exposure bias</source>
        <translation>Belichtingsvertekening</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Focal length</source>
        <translation>Focale lengte</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Max aperture</source>
        <translation>Max. opening</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Metering mode</source>
        <translation>Metermodus</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Subject distance</source>
        <translation>Onderwerpafstand</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>Flash mode</source>
        <translation>Flitsmodus</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="134"/>
        <source>35mm focal length</source>
        <translation>35mm focale lengte</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Lens model</source>
        <translation>Lensmodel</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Contrast</source>
        <translation>Contrast</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Brightness</source>
        <translation>Helderheid</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Exposure program</source>
        <translation>Belichtingsprogramma</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Saturation</source>
        <translation>Verzadiging</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>Sharpness</source>
        <translation>Scherpte</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>White balance</source>
        <translation>Witbalans</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>Digital zoom</source>
        <translation>Digitale zoom</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="153"/>
        <source>EXIF version</source>
        <translation>EXIF-versie</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude reference</source>
        <translation>Breedtegraadverwijzing</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Latitude</source>
        <translation>Breedtegraad</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude reference</source>
        <translation>Lengtegraadverwijzing</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Longitude</source>
        <translation>Lengtegraad</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude reference</source>
        <translation>Hoogteverwijzing</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>Altitude</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="176"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="194"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Property</source>
        <translation>Eigenschap</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Value</source>
        <translation>Waarde</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="31"/>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="61"/>
        <source>Editing shortcuts for action &quot;%1&quot;:</source>
        <translation>Bewerken van sneltoetsen voor actie ‘%1’:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Failed to set shortcuts</source>
        <translation>Instellen mislukt</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
        <translation>Controleer of de gekozen sneltoetsen niet al in gebruik zijn.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="78"/>
        <source>Do nothing</source>
        <translation>Niets doen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="79"/>
        <source>Close the window</source>
        <translation>Venster sluiten</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Toggle maximize</source>
        <translation>Maximaliseren/Demaximaliseren</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="81"/>
        <source>Toggle fullscreen</source>
        <translation>Schermvullende weergave aan/uit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="85"/>
        <source>Zoom in and out</source>
        <translation>In-/Uitzoomen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="86"/>
        <source>View next or previous item</source>
        <translation>Ga naar volgende of vorige item</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="90"/>
        <source>Auto size</source>
        <translation>Automatische grootte</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="91"/>
        <source>Maximized</source>
        <translation>Gemaximaliseerd</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="92"/>
        <source>Windowed</source>
        <translation>Venster</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="96"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation>Rond (geheel getal)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="97"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation>Keil (geheel getal)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="98"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation>Grond (geheel getal)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="99"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation>Systeeminstelling (fractionele schaal)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="122"/>
        <source>Stay on top when start-up</source>
        <translation>Automatisch altijd bovenop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="123"/>
        <source>Use built-in close window animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>Use light-color checkerboard</source>
        <translation>Licht schaakbordpatroon gebruiken</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="125"/>
        <source>Loop the loaded gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>Double-click behavior</source>
        <translation>Dubbelklikgedrag</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>Mouse wheel behavior</source>
        <translation>Scrollwielgedrag</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>Default window size</source>
        <translation>Standaard vensterafmetingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation>HiDPI-schaalfactor - afrondbeleid</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../shortcutedit.cpp" line="109"/>
        <source>No shortcuts</source>
        <translation>Geen sneltoetsen</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <location filename="../shortcutedit.cpp" line="75"/>
        <source>Shortcut #%1</source>
        <translation>Sneltoets #%1</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Pineapple Pictures</source>
        <translation>Pineapple Afbeeldingen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>List supported image format suffixes, and quit program.</source>
        <translation>Toon een lijst met ondersteunde afbeeldingsformaten en sluit af.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>File list.</source>
        <translation>Bestandslijst.</translation>
    </message>
</context>
</TS>
